Process the Time data from SensorLog and Compare to an Expected Timezone
Source:R/ww_process_time.R
ww_process_time.RdProcess the Time data from SensorLog and Compare to an Expected Timezone
Usage
ww_process_time(
data,
expected_timezone = "America/New_York",
tz = "GMT",
apply_tz = TRUE,
check_data = TRUE,
verbose = FALSE,
...
)Arguments
- data
A
data.framefrom ww_read_sensorlog- expected_timezone
Expected Timezone based on the latitude/longitude of the data based on the lat/lon values from SensorLog ( e.g.
"America/New_York"). Set toNULLif not to be checked.- tz
timezone to project the data into. Keeping as
GMTand should have same value forapply_tzto agree (caution: always check data) with ActiGraph, passed to lubridate::as_datetime.- apply_tz
Apply the timezone from the timezone shift from the timezone, e.g. "2025-03-11T14:44:11-04:00" becomes "2025-03-11T18:44:11" if
apply_tz = TRUE, but "2025-03-11T14:44:11" ifapply_tz = FALSE.- check_data
if
TRUEany duplicates for time are checked for.- verbose
print diagnostic messages. Either logical or integer, where higher values are higher levels of verbosity.
- ...
additional arguments to pass to
lutz::tz_lookup_coords()